savannah-cvs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Savannah-cvs] administration/infra/elisp savannah.el


From: Sylvain Beucler
Subject: [Savannah-cvs] administration/infra/elisp savannah.el
Date: Sun, 05 Jun 2005 10:14:42 -0400

CVSROOT:        /cvsroot/administration
Module name:    administration
Branch:         
Changes by:     Sylvain Beucler <address@hidden>        05/06/05 14:14:42

Modified files:
        infra/elisp    : savannah.el 

Log message:
        Fixed a few olddities and emphasized that users oughta use the 
tracker...

CVSWeb URLs:
http://savannah.gnu.org/cgi-bin/viewcvs/administration/administration/infra/elisp/savannah.el.diff?tr1=1.31&tr2=1.32&r1=text&r2=text

Patches:
Index: administration/infra/elisp/savannah.el
diff -u administration/infra/elisp/savannah.el:1.31 
administration/infra/elisp/savannah.el:1.32
--- administration/infra/elisp/savannah.el:1.31 Wed Jun  1 20:08:36 2005
+++ administration/infra/elisp/savannah.el      Sun Jun  5 14:14:42 2005
@@ -47,6 +47,7 @@
 ;;     opening 
 ;;     closing
 ;;     problem (several common problems in registrations)
+;;     confusion (pointpointing differences between two words)
 ;;     reject
 ;;     approve
 ;;
@@ -58,14 +59,16 @@
 ;;
 ;; AUTHORS:
 ;;
 ;;   Loic Dachary, Jaime Villate and Mathieu Roy.  There are some quotes
 ;;   from http://www.gnu.org/licenses/.  Rudy Gevaert imported the changes
 ;;   that Paul A. Crable suggested and added the sections about the LGPL.
 ;;   Elfyn McBratney re-worked sv-closing into sv-closing-reply and
 ;;   sv-closing-resubmit, and added sv-deleted-pending and
 ;;   sv-problem-fdl-info.
 ;;
-;; $Id: savannah.el,v 1.31 2005/06/01 20:08:36 Beuc Exp $
+;; $Id: savannah.el,v 1.32 2005/06/05 14:14:42 Beuc Exp $
 
 ;;
 ;; General
@@ -89,7 +92,7 @@
   ""
   (insert "Please register your project once more with the changes mentioned 
above.
 
-We cannot track projects that have been answered but not approved, so we must 
ask you to re-register the project again whenever you change the registration.  
Make sure to apply all changes requested, so you will only need to re-register 
once.
+Make sure to apply all changes requested, so you will only need to re-register 
once.
 
 The re-registration URL found in our acknowledgment of your earlier 
registration will direct you to the proper location where you can re-register 
your project.
 
@@ -115,6 +118,8 @@
   ""
   (insert "If you are willing to make the changes mentioned above, please 
provide us with an URL to an updated tarball of your project.  Upon review, we 
will reconsider your project for inclusion in Savannah.
 
+To help us better keep track of your registration, please use the tracker's 
web interface following the link below. Do not reply directly, the registration 
process is not driven by e-mail, and we will not receive such replies.
+
 Regards.\n")
   (message "Inserted sv-closing-reply text.")
   )
@@ -611,4 +616,18 @@
   (message "Inserted sv-confusion-eval text.")
   )
 
+
+;; Is the project active (p = predicat :))
+
+(defun sv-active-p ()
+  (interactive)
+  (insert "Hi,
+
+As promised I review your project again.
+
+I see the project is currently empty. Can you give me the status of this 
project? Do you still work on it?\n\n")
+  (message "Inserted sv-active-p text.")
+  )
+
+
 (provide 'savannah)
@@ -58,14 +59,16 @@
 ;; AUTHORS:
 ;;
-;;   Loic Dachary, Jaime Villate and Mathieu Roy.  There are some quotes
-;;   from http://www.gnu.org/licenses/.  Rudy Gevaert imported the changes
-;;   that Paul A. Crable suggested and added the sections about the LGPL.
-;;   Elfyn McBratney re-worked sv-closing into sv-closing-reply and
-;;   sv-closing-resubmit, and added sv-deleted-pending and
-;;   sv-problem-fdl-info.
+;;   Loic Dachary, Jaime Villate and Mathieu Roy.  There are some
+;;   quotes from http://www.gnu.org/licenses/.  Rudy Gevaert imported
+;;   the changes that Paul A. Crable suggested and added the sections
+;;   about the LGPL.  Elfyn McBratney re-worked sv-closing into
+;;   sv-closing-reply and sv-closing-resubmit, and added
+;;   sv-deleted-pending and sv-problem-fdl-info. Sylvain Beucler made
+;;   lots of changes tracked via CVS, with suggestions or patches from
+;;   Jonathan V. Gonzales and Sebastian Wieseler.
 ;;




reply via email to

[Prev in Thread] Current Thread [Next in Thread]